


#include <glib-object.h>
#include "panel-applet-enums.h"


/* enumerations from "/usr/src/ports/gnome-panel/gnome-panel-3.18.1-1.x86_64/src/gnome-panel-3.18.1/libpanel-applet/panel-applet.h" */
#include "/usr/src/ports/gnome-panel/gnome-panel-3.18.1-1.x86_64/src/gnome-panel-3.18.1/libpanel-applet/panel-applet.h"
static const GEnumValue _panel_applet_orient_values[] = {
  { PANEL_APPLET_ORIENT_UP, "PANEL_APPLET_ORIENT_UP", "up" },
  { PANEL_APPLET_ORIENT_DOWN, "PANEL_APPLET_ORIENT_DOWN", "down" },
  { PANEL_APPLET_ORIENT_LEFT, "PANEL_APPLET_ORIENT_LEFT", "left" },
  { PANEL_APPLET_ORIENT_RIGHT, "PANEL_APPLET_ORIENT_RIGHT", "right" },
  { 0, NULL, NULL }
};

GType
panel_applet_orient_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_enum_register_static ("PanelAppletOrient", _panel_applet_orient_values);

  return type;
}

static const GFlagsValue _panel_applet_flags_values[] = {
  { PANEL_APPLET_FLAGS_NONE, "PANEL_APPLET_FLAGS_NONE", "flags-none" },
  { PANEL_APPLET_EXPAND_MAJOR, "PANEL_APPLET_EXPAND_MAJOR", "expand-major" },
  { PANEL_APPLET_EXPAND_MINOR, "PANEL_APPLET_EXPAND_MINOR", "expand-minor" },
  { PANEL_APPLET_HAS_HANDLE, "PANEL_APPLET_HAS_HANDLE", "has-handle" },
  { 0, NULL, NULL }
};

GType
panel_applet_flags_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_flags_register_static ("PanelAppletFlags", _panel_applet_flags_values);

  return type;
}




